********************************************************************************
		*Disaggregated Impacts of Growth on Multidimensional Poverty: 
					*Does the Source of Growth Matter?
********************************************************************************

****************************CLEANING MPI DATA***********************************

/*This do-file cleans the raw mpi data*/

clear all

********************************************************************************
/*
*** Set global(s) (already set in 00 Main do file)
*directory where data (Master.dta) is saved
global data "C:\Users\\`c(username)'\Desktop\reproducibility package\1 data"
*directory where do-files are saved
global code "C:\Users\\`c(username)'\Desktop\reproducibility package\2 do-files"
*directory where results table will be saved
global outputs "C:\Users\\`c(username)'\Desktop\reproducibility package\3 outputs"
*/

********************************************************************************
***load excel file with MPI data
import excel "$data\1 raw\Table_6_Trends_Over_Time_MPI_2023_2.xlsx", sheet("Sheet1") firstrow

********************************************************************************
***clean data
*keep only essential data
drop junk*
drop in 1/9

*
destring ccode_n, replace
drop if ccode_n == .
lab var ccode_n "ISO 3 numeric country code"
lab var ccode "ISO 3 country code"

*encode region
encode region, gen(region_num)
drop region
rename region_num region


*gen years
gen year1 = substr(Year1, length(Year1)-3, 4)
drop Year1

gen year2 = substr(Year2, length(Year2)-3, 4)
drop Year2

*bring into long format and destring
gen n = _n
expand 2
sort n
by n: gen n2 = _n

foreach x in year mpi pop nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets{
	gen `x' = `x'1 if n2 == 1
	replace `x' = `x'2 if n2 == 2
	destring `x', replace
}
*

foreach y in nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets{
	replace `y' = `y' / 100 
}
*

duplicates drop ccode_n year, force

***
*fix ccode from Sudan (to match with WB and productivity)
replace ccode_n = 736 if ccode_n == 729

***
keep year ccode_n ccode country region mpi pop nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets
order year ccode_n ccode country region mpi 

***
save "$data\2 clean\mpi.dta", replace

 







