********************************************************************************
		*Disaggregated Impacts of Growth on Multidimensional Poverty: 
					*Does the Source of Growth Matter?
********************************************************************************

****************************CLEANING SUSTAINABLE GROWTH DATA*********************

/*This do-file cleans the raw data to apply Mahler (2021) methodology to calculate
sustainable and unsustainable growth*/

clear all

********************************************************************************
/*
*** Set global(s) (already set in 00 Main do file)
*directory where data (Master.dta) is saved
global data "C:\Users\\`c(username)'\Desktop\reproducibility package\1 data"
*directory where do-files are saved
global code "C:\Users\\`c(username)'\Desktop\reproducibility package\2 do-files"
*directory where results table will be saved
global outputs "C:\Users\\`c(username)'\Desktop\reproducibility package\3 outputs"
*/

foreach y in co2_damage cons_fc emission_damage gni nr_depletion pop{
********************************************************************************
import excel "$data\1 raw\\`y'.xls", sheet("Data") firstrow

***clean data
rename CountryName country
rename CountryCode ccode
drop IndicatorName IndicatorCode

* List of variables to rename, from E to BO 
local vars E F G H I J K L M N O P Q R S T U V W X Y Z AA AB AC AD AE AF AG AH AI AJ AK AL AM AN AO AP AQ AR AS AT AU AV AW AX AY AZ BA BB BC BD BE BF BG BH BI BJ BK BL BM BN BO BP

* Initialize a counter for the year
local year = 1960

* Loop over the variables in the list
foreach var of local vars {
    * Construct the new variable name
    local new_name = "`y'`year'"
    
    * Rename the variable
    rename `var' `new_name'
    
    * Increment the year by 1
    local year = `year' + 1
}
*

*reshape to long
reshape long `y', i(country) j(year)

*save
save "$data\2 clean\\`y'.dta", replace
clear
}
*

* merge data
use "$data\2 clean\co2_damage.dta"
merge 1:1 ccode year using "$data\2 clean\cons_fc.dta"
drop _merge
merge 1:1 ccode year using "$data\2 clean\emission_damage.dta"
drop _merge
merge 1:1 ccode year using "$data\2 clean\gni.dta"
drop _merge
merge 1:1 ccode year using "$data\2 clean\nr_depletion.dta"
drop _merge
merge 1:1 ccode year using "$data\2 clean\pop.dta"
drop _merge


*gen monetary values
foreach y in co2_damage cons_fc emission_damage nr_depletion{
	gen `y'_us = (`y' / 100 ) * gni
}
*
drop co2_damage cons_fc emission_damage nr_depletion

*gen per capita values
foreach y in gni co2_damage_us cons_fc_us emission_damage_us nr_depletion_us{
	gen `y'pc = `y' / pop
}
*
drop gni co2_damage_us cons_fc_us emission_damage_us nr_depletion_us

rename (co2_damage_uspc cons_fc_uspc emission_damage_uspc nr_depletion_uspc) (co2_damage_pc cons_fc_pc emission_damage_pc nr_depletion_pc)

lab var co2_damage_pc "CO2 damage per capita (constant 2015 US$)"
lab var cons_fc_pc "Consumption of fixed capital per capita (constant 2015 US$)"
lab var emission_damage_pc "Emission damage (excl. CO2) per capita (constant 2015 US$)"
lab var nr_depletion_pc "Natural resource depletion per capita (constant 2015 US$)"
lab var gnipc "GNI (constant 2015 US$)"

*generate unsustainable growth
gen unsust_growthpc = co2_damage_pc + cons_fc_pc + emission_damage_pc + nr_depletion_pc 
lab var unsust_growth "Unsustainable growth (const. 2015 US$)"
*generate unsustainable growth
gen sust_growthpc = gnipc - (co2_damage_pc + cons_fc_pc + emission_damage_pc + nr_depletion_pc)
lab var sust_growth "Sustainable growth (const. 2015 US$)"

drop pop gnipc co2_damage_pc cons_fc_pc emission_damage_pc nr_depletion_pc
replace sust_growth = 0 if sust_growth<0


*generate country codes
kountry ccode, from(iso3c) to(iso3n) marker
*fix Kosovo and assing 689 as ccode_n
replace MARKER = 1 if country == "Kosovo"
replace NAMES_STD = "Kosovo" if country == "Kosovo"
replace _ISO3N_ = 689 if country == "Kosovo"
*drop aggregats (note, some small islands will also be deleted but they are anyway not part of the analysis)
drop if MARKER == 0
drop MARKER country
rename _ISO3N_ ccode_n
rename NAMES_STD country

*fix Yugoslavia and serbia mix up from kountry
replace country = "Serbia" if ccode == "SRB"
replace ccode_n = 688 if ccode == "SRB"


order year ccode ccode_n country 

*save
save "$data\2 clean\sustainable_growth.dta", replace



