********************************************************************************
		*Disaggregated Impacts of Growth on Multidimensional Poverty: 
					*Does the Source of Growth Matter?
********************************************************************************

****************************CLEANING RESOURCE RENTS DATA*********************

/*This do-file cleans the raw resource rents data and generates the variable 
resource dependent*/

clear all

********************************************************************************
/*
*** Set global(s) (already set in 00 Main do file)
*directory where data (Master.dta) is saved
global data "C:\Users\\`c(username)'\Desktop\reproducibility package\1 data"
*directory where do-files are saved
global code "C:\Users\\`c(username)'\Desktop\reproducibility package\2 do-files"
*directory where results table will be saved
global outputs "C:\Users\\`c(username)'\Desktop\reproducibility package\3 outputs"
*/

********************************************************************************
***load GDP data
import excel "$data\1 raw\API_NY.GDP.TOTL.RT.ZS_DS2_en_excel_v2_1537790.xls", sheet("Data") firstrow

***clean data
rename CountryName country
rename CountryCode ccode
drop IndicatorName IndicatorCode

* List of variables to rename, from E to BO 
local vars E F G H I J K L M N O P Q R S T U V W X Y Z AA AB AC AD AE AF AG AH AI AJ AK AL AM AN AO AP AQ AR AS AT AU AV AW AX AY AZ BA BB BC BD BE BF BG BH BI BJ BK BL BM BN BO BP

* Initialize a counter for the year
local year = 1960

* Loop over the variables in the list
foreach var of local vars {
    * Construct the new variable name
    local new_name = "res_rent`year'"
    
    * Rename the variable
    rename `var' `new_name'
    
    * Increment the year by 1
    local year = `year' + 1
}
*

*reshape to long
reshape long res_rent, i(country) j(year)
lab var res_rent "Natural resource rents (% of GDP)"

*generate country codes
kountry ccode, from(iso3c) to(iso3n) marker
*fix Kosovo and assing 689 as ccode_n
replace MARKER = 1 if country == "Kosovo"
replace NAMES_STD = "Kosovo" if country == "Kosovo"
replace _ISO3N_ = 689 if country == "Kosovo"
*drop aggregats (note, some small islands will also be deleted but they are anyway not part of the analysis)
drop if MARKER == 0
drop MARKER country
rename _ISO3N_ ccode_n
rename NAMES_STD country

*fix Yugoslavia and serbia mix up from kountry
replace country = "Serbia" if ccode == "SRB"
replace ccode_n = 688 if ccode == "SRB"


sort ccode_n year
by ccode_n: gen m5_res_rent = (res_rent[_n-4] + res_rent[_n-3] + res_rent[_n-2] + res_rent[_n-1] + res_rent) / 5

gen res_dep = 0 if m5_res_rent != .
replace res_dep = 1 if m5_res_rent > 10 & m5_res_rent != .
lab var res_dep "Resource dependent"

drop m5_res_rent

order year ccode ccode_n country res_rent


*save
save "$data\2 clean\res_rent.dta", replace
