********************************************************************************
		*Disaggregated Impacts of Growth on Multidimensional Poverty: 
					*Does the Source of Growth Matter?
********************************************************************************

****************************MERGING CLEANED DATA *******************************

/*This do-file merges the clean data and generates the Master.dta file*/

clear all

********************************************************************************
/*
*** Set global(s) (already set in 00 Main do file)
*directory where data (Master.dta) is saved
global data "C:\Users\\`c(username)'\Desktop\reproducibility package\1 data"
*directory where do-files are saved
global code "C:\Users\\`c(username)'\Desktop\reproducibility package\2 do-files"
*directory where results table will be saved
global outputs "C:\Users\\`c(username)'\Desktop\reproducibility package\3 outputs"
*/


***other globals
global dep_var "mpi nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets"
global ind_var "gdppc gini lpe tfp capdeep hc cpc ipc gpc xpc mpc unsust_growthpc sust_growthpc"
global initial_control "mpi"


********************************************************************************
***combine all datasets
*load MPI data
use "$data\2 clean\mpi.dta", clear
*merge with GPD data
merge 1:1 ccode_n year using "$data\2 clean\gdppc"
drop _merge
*merge with gini
merge 1:1 ccode_n year using "$data\2 clean\gini.dta"
drop _merge
*merge with income group
merge 1:1 year ccode_n using "$data\2 clean\income_groups.dta"
drop _merge
*merge with productivity
merge 1:1 ccode_n year using "$data\2 clean\productivity.dta"
drop _merge
*merge with CIGXM
merge 1:1 ccode_n year using "$data\2 clean\cigxm.dta"
drop _merge
*merge with sustainable growth
merge 1:1 ccode_n year using "$data\2 clean\sustainable_growth.dta"
drop _merge
*merge with resource rents
merge 1:1 ccode_n year using "$data\2 clean\res_rent.dta"
drop _merge

sort ccode_n year


********************************************************************************
***generate necessary variables for the analysis

*generate human capital contribution's to productivity growth rate 
gen dhc = dlpe - dcapdeep - dtfp
lab var dhc "human capital contr. growth"

*generate levels for the growth rates of dlpe dftp dcapdeep dhc 
foreach d of var dlpe dtfp dcapdeep dhc{
by ccode_n: gen junk1 = sum(!missing(`d')) if !missing(`d')
gen junk2 = junk1[_n+1]
gen `d'_level = 100 if junk2 == 1
by ccode_n: replace `d'_level = `d'_level[_n-1] + (`d'_level[_n-1] * (`d'/100)) if `d' != .
drop junk1 junk2
}
*
rename (dlpe_level dtfp_level dcapdeep_level dhc_level) (lpe tfp capdeep hc)

***
*generate 5 year mean of independent variable (lagged) as in Santos
foreach v of var $ind_var{
gen m5_`v' = (`v'[_n-5] + `v'[_n-4] + `v'[_n-3] + `v'[_n-2] + `v'[_n-1]) / 5
}
*
global m5_var "m5_gdppc m5_gini m5_lpe m5_tfp m5_capdeep m5_hc m5_cpc m5_ipc m5_gpc m5_xpc m5_mpc m5_unsust_growthpc m5_sust_growthpc"

*generate logarithm
foreach v of var $dep_var $ind_var $m5_var{
gen l_`v' = ln(`v')
}
*

*generate 5 year lag of the independent log variables
foreach v of var $ind_var {
by ccode_n: gen L5_l_`v' = l_`v'[_n-5]
}
*

*gen 5 year spells of the compounded annualized growth rates for the independent variables
forvalue s = 5(1)5{
local t = `s' - 1
foreach v of var $ind_var {
by ccode_n: gen dl`s'_`v' = (l_`v' - l_`v'[_n-`t']) / `s'
}
}
*

*drop not-needed observations and variables
drop if mpi == .
drop dlpe dcapdeep dtfp dhc 


*generate the compounded annualized growth rates per spell and year difference between spells for the dependent variables and independent variables
by ccode_n: gen dyear = year - year[_n-1] 
foreach b of var $dep_var $ind_var $m5_var{
by ccode_n: gen dl_`b' = (l_`b' - l_`b'[_n-1]) / dyear
}
*

*generate the change in the dependent variable by spell for the semi-elasticity calculation 
foreach a of var $dep_var{
	by ccode_n: gen d_`a' = (`a' - `a'[_n-1]) / dyear
}
*

*generate the compounded annualized growth rates per spell + 5 years lagged 
by ccode_n: gen d5year = dyear + 5 
foreach b of var $ind_var{
by ccode_n: gen c5_dl_`b' = (l_`b' - L5_l_`b'[_n-1]) / d5year
}
*

*lag the 5 year spell compounded growth rate of the independent variables for which we assume a lagged impact (growth rates)
forvalue s = 5(1)5{
foreach v of var $ind_var {
by ccode_n: gen L_dl`s'_`v' = dl`s'_`v'[_n-1]
}
}
*

*lag potential control variable (measured in logs)
foreach v of var $dep_var {
by ccode_n: gen L_l_`v' = l_`v'[_n-1]
}
*

order year ccode_n ccode country region mpi pop nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets gdppc lpxr lpe tfp capdeep hc 

format ccode %4s
format country %35s

lab var dl_mpi "MPI"
lab var dl_gdppc "Change in GDP (current)"
lab var L_dl5_gdppc "Change in GDP (lagged)"
lab var c5_dl_gdppc "Change in GDP (current + lagged)"
lab var dl_m5_gdppc "Change in GDP (following Santos and Balasubramanian)"
lab var L_l_mpi "Initial level of MPI"
lab var dl_gini "Change in Gini (current)"

lab var dl_nutrition "Nutrition"
lab var dl_child_mortality "Child mortality"
lab var	dl_years_of_schooling "Years of schooling"
lab var	dl_school_attendance "School attendance"
lab var	dl_cooking_fuel	"Cooking fuel"
lab var dl_sanitation "Sanitation"
lab var	dl_drinking_water "Drinking water"
lab var dl_electricity "Electricity"
lab var dl_housing "Housing"
lab var dl_assets "Assets"

lab var c5_dl_lpe "Change in labour productivity"
lab var c5_dl_tfp "Change in TFP"
lab var c5_dl_capdeep "Change in physical capital"
lab var c5_dl_hc "Change in human capital"

lab var c5_dl_cpc "Change in consumption" 
lab var c5_dl_ipc "Change in investment"
lab var c5_dl_gpc "Change in government spending"
lab var c5_dl_xpc "Change in export"
lab var c5_dl_mpc "Change in import"

lab var c5_dl_unsust_growthpc "Unsustainable change in GNI"
lab var c5_dl_sust_growthpc "Sustainable change in GNI"

lab var c5_dl_gini "Change in Gini"

lab var dl_m5_lpe "Change in labour productivity (following Santos and Balasubramanian)"
lab var dl_m5_tfp "Change in TFP (following Santos and Balasubramanian)"
lab var dl_m5_capdeep "Change in physical capital (following Santos and Balasubramanian)"
lab var dl_m5_hc "Change in human capital (following Santos and Balasubramanian)"
lab var dl_m5_cpc "Change in consumption (following Santos and Balasubramanian)" 
lab var dl_m5_ipc "Change in investment (following Santos and Balasubramanian)"
lab var dl_m5_gpc "Change in government spending (following Santos and Balasubramanian)"
lab var dl_m5_xpc "Change in export (following Santos and Balasubramanian)"
lab var dl_m5_mpc "Change in import (following Santos and Balasubramanian)"
lab var dl_m5_unsust_growthpc "Unsustainable change in GNI (following Santos and Balasubramanian)"
lab var dl_m5_sust_growthpc "Sustainable change in GNI (following Santos and Balasubramanian)"

lab var l_mpi "(log) MPI"
lab var l_nutrition "(log) Nutrition"
lab var l_child_mortality "(log) Child mortality"
lab var	l_years_of_schooling "(log) Years of schooling"
lab var	l_school_attendance "(log) School attendance"
lab var	l_cooking_fuel	"(log) Cooking fuel"
lab var l_sanitation "(log) Sanitation"
lab var	l_drinking_water "(log) Drinking water"
lab var l_electricity "(log) Electricity"
lab var l_housing "(log) Housing"
lab var l_assets "(log) Assets"

lab var l_gdppc "(log) GDP"
lab var l_lpe"(log) labour productivity"
lab var l_tfp"(log) TFP"
lab var l_capdeep"(log) physical capital"
lab var l_hc"(log) human capital"
lab var l_cpc"(log) consumption" 
lab var l_ipc"(log) investment"
lab var l_gpc"(log) government spending"
lab var l_xpc"(log) export"
lab var l_mpc"(log) import"
lab var l_unsust_growthpc"(log) unsustainable GNI"
lab var l_sust_growthpc"(log) sustainable GNI"

lab var d_mpi "MPI"
lab var d_nutrition "Nutrition"
lab var d_child_mortality "Child mortality"
lab var	d_years_of_schooling "Years of schooling"
lab var	d_school_attendance "School attendance"
lab var	d_cooking_fuel	"Cooking fuel"
lab var d_sanitation "Sanitation"
lab var	d_drinking_water "Drinking water"
lab var d_electricity "Electricity"
lab var d_housing "Housing"
lab var d_assets "Assets"

lab var dyear "Spell length in years"

*******************************************************************************
***save MASTER file
save "$data\Master.dta", replace
