********************************************************************************
		*Disaggregated Impacts of Growth on Multidimensional Poverty: 
					*Does the Source of Growth Matter?
********************************************************************************

****************************SUMMARY STATISTICS**********************************

/*This do-files creates the summary statistics shown in the paper
*/

clear all

********************************************************************************
/*
*** Set global(s) (already set in 00 Main do file)
*directory where data (Master.dta) is saved
global data "C:\Users\\`c(username)'\Desktop\reproducibility package\1 data"
*directory where do-files are saved
global code "C:\Users\\`c(username)'\Desktop\reproducibility package\2 do-files"
*directory where results table will be saved
global outputs "C:\Users\\`c(username)'\Desktop\reproducibility package\3 outputs"
*/

********************************************************************************
***load Master data set
use "$data\Master.dta", clear

********************************************************************************
***Data for Table 2: Regions of the sample

***gen sample
qui reg dl_mpi dl_gdppc, vce(robust)
gen s = e(sample)

***number of countries
egen country_count = tag(country) if s==1
count if country_count

***list of the six regions and the number of countries for each region
ta region if country_count == 1 & s == 1
***list of the six regions and the number of spells for each region
ta region if s == 1
***first year for each region
sort ccode_n year
by ccode_n: gen L_year = year[_n-1]
forvalues x = 1/6{
	ta L_year if s==1 & region==`x'
}
*
***last year for each region
forvalues x = 1/6{
	ta year if s==1 & region==`x'
}
*

********************************************************************************
***Data for Table A1: List of countries
*table with countries by region and years of the surveys
sort ccode year
list country region L_year year if s==1


********************************************************************************
***Table A2: Summary statistics
global sumx dl_mpi dyear dl_nutrition dl_child_mortality dl_years_of_schooling dl_school_attendance dl_cooking_fuel dl_sanitation dl_drinking_water dl_electricity dl_housing dl_assets c5_dl_gdppc c5_dl_lpe c5_dl_tfp c5_dl_capdeep c5_dl_hc c5_dl_cpc c5_dl_ipc c5_dl_gpc c5_dl_xpc c5_dl_mpc c5_dl_sust_growthpc c5_dl_unsust_growthpc  
estimates clear 
estpost tabstat $sumx if s==1, stat(N mean sd min max) columns(statistics) 
esttab using "$outputs\Table A2.rtf", replace cells("count(fmt(%9.0fc)) mean(fmt(%9.3f)) sd(fmt(%9.3f)) min(fmt(%9.3f)) max(fmt(%9.3f))") label noobs nodepvars nonumbers collabels("N" "Mean" "St.d." "Min" "Max") plain


