********************************************************************************
		*Disaggregated Impacts of Growth on Multidimensional Poverty: 
					*Does the Source of Growth Matter?
********************************************************************************

****************************ANALYSIS********************************************

clear all

********************************************************************************
/*
*** Set global(s) (already set in 00 Main do file)
*directory where data (Master.dta) is saved
global data "C:\Users\\`c(username)'\Desktop\reproducibility package\1 data"
*directory where do-files are saved
global code "C:\Users\\`c(username)'\Desktop\reproducibility package\2 do-files"
*directory where results table will be saved
global outputs "C:\Users\\`c(username)'\Desktop\reproducibility package\3 outputs"
*/

***load Master data set
use "$data\Master.dta", clear

********************************************************************************
***Analyisis
********************************************************************************
***Table 3: MPI and GDP
qui reg dl_mpi dl_gdppc, vce(robust)
gen s = e(sample)
by ccode_n: egen s_w = total(s)
replace s_w = 1/s_w
*model 1
reg dl_mpi dl_gdppc [aweight = s_w], vce(robust)
outreg2 using "$outputs\mpi_gdp", excel label bdec(3) replace
*model 2
reg dl_mpi dl_gdppc L_dl5_gdppc [aweight = s_w], vce(robust)
outreg2 using "$outputs\mpi_gdp", excel label bdec(3) append
*model 3
reg dl_mpi c5_dl_gdppc [aweight = s_w], vce(robust)
outreg2 using "$outputs\mpi_gdp", excel label bdec(3) append
*model 4
reg dl_mpi dl_m5_gdppc [aweight = s_w] if dyear >= 5, vce(robust)
outreg2 using "$outputs\mpi_gdp", excel label bdec(3) append
*model 5
reg dl_mpi c.c5_dl_gdppc##c.L_l_mpi [aweight = s_w], vce(robust)
outreg2 using "$outputs\mpi_gdp", excel label bdec(3) append
*model 6
reg dl_mpi c5_dl_gdppc dl_gini [aweight = s_w], vce(robust)
outreg2 using "$outputs\mpi_gdp", excel label bdec(3) append

*furhter regressions for footnote 3
reg dl_mpi c5_dl_gdppc L_dl5_gini [aweight = s_w], vce(robust)
reg dl_mpi c5_dl_gdppc dl_gini L_dl5_gini [aweight = s_w], vce(robust)
reg dl_mpi c.c5_dl_gdppc##c.dl_gini [aweight = s_w], vce(robust)

drop s s_w

********************************************************************************
***Table 4: MPI components and GDP
local first = "nutrition"
local rest = "child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach comp in `first' `rest'{
    // Your statistical command here
    qui reg dl_`comp' dl_gdppc L_dl5_gdppc, vce(robust)
	gen s = e(sample)
	by ccode_n: egen s_w = total(s)
	replace s_w = 1/s_w
	reg dl_`comp' dl_gdppc L_dl5_gdppc [aweight = s_w], vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `comp' == `first' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_comp_gdp", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_comp_gdp", excel label bdec(3) append
    }
drop s s_w
}
*

********************************************************************************
***Table A3: MPI components and GDP (current+lagged) for appendix 
local first = "nutrition"
local rest = "child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach comp in `first' `rest'{
    // Your statistical command here
    qui reg dl_`comp' c5_dl_gdppc, vce(robust)
	gen s = e(sample)
	by ccode_n: egen s_w = total(s)
	replace s_w = 1/s_w
	reg dl_`comp' c5_dl_gdppc [aweight = s_w], vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `comp' == `first' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_comp_gdp_c1", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_comp_gdp_c1", excel label bdec(3) append
    }
drop s s_w
}
*



********************************************************************************
***Table 5: MPI and GDP by income groups and resource dependency 
tabulate inc_group, gen(inc_dummy_)
*Model 1-3
forvalues inc_gr =1/3 {
    // Your statistical command here
    qui reg dl_mpi c.c5_dl_gdppc##i.inc_dummy_`inc_gr', vce(robust)
	gen s = e(sample)
	by ccode_n: egen s_w = total(s)
	replace s_w = 1/s_w
	reg dl_mpi c.c5_dl_gdppc##i.inc_dummy_`inc_gr' [aweight = s_w], vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `inc_gr' == 1 {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_gdp_inc_gr", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_gdp_inc_gr", excel label bdec(3) append
    }
drop s s_w
}
*
***Addition: Reserouce dependency
*Model 4
qui reg dl_mpi c.c5_dl_gdppc##i.res_dep, vce(robust)
	gen s = e(sample)
	by ccode_n: egen s_w = total(s)
	replace s_w = 1/s_w
reg dl_mpi c.c5_dl_gdppc##i.res_dep [aweight = s_w], vce(robust)
    outreg2 using "$outputs\mpi_gdp_inc_gr", excel label bdec(3) append
drop s s_w


********************************************************************************
***Table A4: MPI components and GDP by income group
local first_dep = "mpi"
local rest_dep = "nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach dep in `first_dep' `rest_dep'{
forvalues inc_gr =1/3 {
    // Your statistical command here
    qui reg dl_`dep' c.c5_dl_gdppc##i.inc_dummy_`inc_gr', vce(robust)
	gen s = e(sample)
	by ccode_n: egen s_w = total(s)
	replace s_w = 1/s_w
	reg dl_`dep' c.c5_dl_gdppc##i.inc_dummy_`inc_gr' [aweight = s_w], vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `inc_gr' == `first_dep' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_gdp_inc_gr_`inc_gr'", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_gdp_inc_gr_`inc_gr'", excel label bdec(3) append
    }
drop s s_w
}
}
*
drop inc_dummy*


********************************************************************************
***Table 6: MPI and GDP by region
tabulate region, gen(region_dummy_)

forvalues region = 1/6 {
    // Your statistical command here
    qui reg dl_mpi c.c5_dl_gdppc##i.region_dummy_`region', vce(robust)
	gen s = e(sample)
	by ccode_n: egen s_w = total(s)
	replace s_w = 1/s_w
	reg dl_mpi c.c5_dl_gdppc##i.region_dummy_`region' [aweight = s_w], vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `region' == 1 {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_gdp_region", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_gdp_region", excel label bdec(3) append
    }
drop s s_w
}
*


********************************************************************************
***Table A5: MPI components and GDP by region
local first_dep = "mpi"
local rest_dep = "nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach dep in `first_dep' `rest_dep'{
forvalues region =1/6 {
    // Your statistical command here
    qui reg dl_`dep' c.c5_dl_gdppc##i.region_dummy_`region', vce(robust)
	gen s = e(sample)
	by ccode_n: egen s_w = total(s)
	replace s_w = 1/s_w
	reg dl_`dep' c.c5_dl_gdppc##i.region_dummy_`region' [aweight = s_w], vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `dep' == `first_dep' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_gdp_region_`region'", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_gdp_region_`region'", excel label bdec(3) append
    }
drop s s_w
}
}
*
drop region_dummy*


********************************************************************************
***Table 7: MPI and advanced growth measures (Model 1)
qui reg dl_mpi c5_dl_lpe, vce(robust)
gen s = e(sample)
by ccode_n: egen s_w = total(s)
replace s_w = 1/s_w
reg dl_mpi c5_dl_lpe [aweight = s_w], vce(robust)
outreg2 using "$outputs\mpi_growth", excel label bdec(3) replace
drop s s_w

***Table 7: MPI and advanced growth measures (Model 2)
qui reg dl_mpi c5_dl_tfp c5_dl_capdeep c5_dl_hc, vce(robust)
gen s = e(sample)
by ccode_n: egen s_w = total(s)
replace s_w = 1/s_w
reg dl_mpi c5_dl_tfp c5_dl_capdeep c5_dl_hc [aweight = s_w], vce(robust)
outreg2 using "$outputs\mpi_growth", excel label bdec(3) append
drop s s_w

***Table 7: MPI and advanced growth measures (Model 3)
qui reg dl_mpi c5_dl_cpc c5_dl_ipc c5_dl_gpc c5_dl_xpc c5_dl_mpc, vce(robust)
gen s = e(sample)
by ccode_n: egen s_w = total(s)
replace s_w = 1/s_w
reg dl_mpi c5_dl_cpc c5_dl_ipc c5_dl_gpc c5_dl_xpc c5_dl_mpc [aweight = s_w], vce(robust)
outreg2 using "$outputs\mpi_growth", excel label bdec(3) append
drop s s_w

***Table 7: MPI and advanced growth measures (Model 4)
qui reg dl_mpi c5_dl_sust_growthpc c5_dl_unsust_growthpc, vce(robust)
gen s = e(sample)
by ccode_n: egen s_w = total(s)
replace s_w = 1/s_w
reg dl_mpi c5_dl_sust_growthpc c5_dl_unsust_growthpc [aweight = s_w], vce(robust)
outreg2 using "$outputs\mpi_growth", excel label bdec(3) append
drop s s_w


********************************************************************************
***Table A6: MPI components and labour productivity
local first = "nutrition"
local rest = "child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach comp in `first' `rest'{
    // Your statistical command here
    qui reg dl_`comp' c5_dl_lpe, vce(robust)
	gen s = e(sample)
	by ccode_n: egen s_w = total(s)
	replace s_w = 1/s_w
	reg dl_`comp' c5_dl_lpe [aweight = s_w], vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `comp' == `first' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_lpe", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_lpe", excel label bdec(3) append
    }
drop s s_w
}
*


********************************************************************************
***Table A7: MPI components and labour productivity components
local first = "nutrition"
local rest = "child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach comp in `first' `rest'{
    // Your statistical command here
    qui reg dl_`comp' c5_dl_tfp c5_dl_capdeep c5_dl_hc, vce(robust)
	gen s = e(sample)
	by ccode_n: egen s_w = total(s)
	replace s_w = 1/s_w
	reg dl_`comp' c5_dl_tfp c5_dl_capdeep c5_dl_hc [aweight = s_w], vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `comp' == `first' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_lp_components", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_lp_components", excel label bdec(3) append
    }
drop s s_w
}
*

********************************************************************************
***Table A8: MPI components and expenditure approach components
local first = "nutrition"
local rest = "child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach comp in `first' `rest'{
    // Your statistical command here
    qui reg dl_`comp' c5_dl_cpc c5_dl_ipc c5_dl_gpc c5_dl_xpc c5_dl_mpc, vce(robust)
	gen s = e(sample)
	by ccode_n: egen s_w = total(s)
	replace s_w = 1/s_w
	reg dl_`comp' c5_dl_cpc c5_dl_ipc c5_dl_gpc c5_dl_xpc c5_dl_mpc [aweight = s_w], vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `comp' == `first' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_components_cigxm", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_components_cigxm", excel label bdec(3) append
    }
drop s s_w
}
*

********************************************************************************
***Table A9: MPI components and sustainable growth
local first = "nutrition"
local rest = "child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach comp in `first' `rest'{
    // Your statistical command here
    qui reg dl_`comp' c5_dl_sust_growthpc c5_dl_unsust_growthpc, vce(robust)
	gen s = e(sample)
	by ccode_n: egen s_w = total(s)
	replace s_w = 1/s_w
	reg dl_`comp' c5_dl_sust_growthpc c5_dl_unsust_growthpc [aweight = s_w], vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `comp' == `first' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_components_sust_growth", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_components_sust_growth", excel label bdec(3) append
    }
drop s s_w
}
*

