********************************************************************************
		*Disaggregated Impacts of Growth on Multidimensional Poverty: 
					*Does the Source of Growth Matter?
********************************************************************************

****************************ROBUSTNESS CHECK GINI*******************************

clear all

********************************************************************************
/*
*** Set global(s) (already set in 00 Main do file)
*directory where data (Master.dta) is saved
global data "C:\Users\\`c(username)'\Desktop\reproducibility package\1 data"
*directory where do-files are saved
global code "C:\Users\\`c(username)'\Desktop\reproducibility package\2 do-files"
*directory where results table will be saved
global outputs "C:\Users\\`c(username)'\Desktop\reproducibility package\3 outputs"
*/

***load Master data set
use "$data\Master.dta", clear

********************************************************************************
***Table A10: MPI components, GDP, and Gini
local first = "mpi"
local rest = "nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach comp in `first' `rest'{
    // Your statistical command here
    qui reg dl_`comp' c5_dl_gdppc c5_dl_gini , vce(robust)
	gen s = e(sample)
	by ccode_n: egen s_w = total(s)
	replace s_w = 1/s_w
	reg dl_`comp' c5_dl_gdppc c5_dl_gini [aweight = s_w], vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `comp' == `first' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_gdp_gini", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_gdp_gini", excel label bdec(3) append
    }
drop s s_w
}
*

/*
***The following regressions are not shown in the paper for space reasons

********************************************************************************
***Table: MPI components, labour productivity, and Gini
local first = "mpi"
local rest = "nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach comp in `first' `rest'{
    // Your statistical command here
    qui reg dl_`comp' c5_dl_lpe c5_dl_gini, vce(robust)
	gen s = e(sample)
	by ccode_n: egen s_w = total(s)
	replace s_w = 1/s_w
	reg dl_`comp' c5_dl_lpe c5_dl_gini [aweight = s_w], vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `comp' == `first' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_lpe_gini", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_lpe_gini", excel label bdec(3) append
    }
drop s s_w
}
*

********************************************************************************
***Table: MPI components, labour productivity components, and Gini
local first = "mpi"
local rest = "nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach comp in `first' `rest'{
    // Your statistical command here
    qui reg dl_`comp' c5_dl_tfp c5_dl_capdeep c5_dl_hc c5_dl_gini, vce(robust)
	gen s = e(sample)
	by ccode_n: egen s_w = total(s)
	replace s_w = 1/s_w
	reg dl_`comp' c5_dl_tfp c5_dl_capdeep c5_dl_hc c5_dl_gini [aweight = s_w], vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `comp' == `first' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_lp_components_gini", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_lp_components_gini", excel label bdec(3) append
    }
drop s s_w
}
*

********************************************************************************
***Table: MPI components, expenditure approach components, and Gini
local first = "mpi"
local rest = "nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach comp in `first' `rest'{
    // Your statistical command here
    qui reg dl_`comp' c5_dl_cpc c5_dl_ipc c5_dl_gpc c5_dl_xpc c5_dl_mpc c5_dl_gini, vce(robust)
	gen s = e(sample)
	by ccode_n: egen s_w = total(s)
	replace s_w = 1/s_w
	reg dl_`comp' c5_dl_cpc c5_dl_ipc c5_dl_gpc c5_dl_xpc c5_dl_mpc c5_dl_gini[aweight = s_w], vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `comp' == `first' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_components_cigxm_gini", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_components_cigxm_gini", excel label bdec(3) append
    }
drop s s_w
}
*

********************************************************************************
***Table: MPI components, sustainable growth and Gini
local first = "mpi"
local rest = "nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach comp in `first' `rest'{
    // Your statistical command here
    qui reg dl_`comp' c5_dl_sust_growthpc c5_dl_unsust_growthpc c5_dl_gini, vce(robust)
	gen s = e(sample)
	by ccode_n: egen s_w = total(s)
	replace s_w = 1/s_w
	reg dl_`comp' c5_dl_sust_growthpc c5_dl_unsust_growthpc c5_dl_gini [aweight = s_w], vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `comp' == `first' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_components_sust_growth_gini", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_components_sust_growth_gini", excel label bdec(3) append
    }
drop s s_w
}
*




