********************************************************************************
		*Disaggregated Impacts of Growth on Multidimensional Poverty: 
					*Does the Source of Growth Matter?
********************************************************************************

****************************ROBUSTNESS CHECK BETA REGRESSION********************

clear all

********************************************************************************
/*
*** Set global(s) (already set in 00 Main do file)
*directory where data (Master.dta) is saved
global data "C:\Users\\`c(username)'\Desktop\reproducibility package\1 data"
*directory where do-files are saved
global code "C:\Users\\`c(username)'\Desktop\reproducibility package\2 do-files"
*directory where results table will be saved
global outputs "C:\Users\\`c(username)'\Desktop\reproducibility package\3 outputs"
*/

***load Master data set
use "$data\Master.dta", clear

********************************************************************************
***Table A12: MPI, MPI components and GDP 
local first = "mpi"
local rest = "nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach comp in `first' `rest'{
    // Your statistical command here
	betafit `comp' , muvar(l_gdppc) vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `comp' == `first' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_gdp_beta", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_gdp_beta", excel label bdec(3) append
    }
}
*

/*
***The following regressions are not shown in the paper for space reasons

********************************************************************************
***Table: MPI, MPI components and labour productivity
local first = "mpi"
local rest = "nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach comp in `first' `rest'{
    // Your statistical command here
	betafit `comp', muvar(l_lpe) vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `comp' == `first' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_lpe_beta", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_lpe_beta", excel label bdec(3) append
    }
}
*


********************************************************************************
***Table: MPI components and labour productivity components
local first = "mpi"
local rest = "nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach comp in `first' `rest'{
    // Your statistical command here
	betafit `comp', muvar(l_tfp l_capdeep l_hc) vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `comp' == `first' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_lp_components_beta", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_lp_components_beta", excel label bdec(3) append
    }
}
*

********************************************************************************
***Table: MPI components and expenditure approach components
local first = "mpi"
local rest = "nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach comp in `first' `rest'{
    // Your statistical command here
	betafit `comp', muvar(l_cpc l_ipc l_gpc l_xpc l_mpc) vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `comp' == `first' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_components_cigxm_beta", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_components_cigxm_beta", excel label bdec(3) append
    }
}
*

********************************************************************************
***Table: MPI components and sustainable growth
local first = "mpi"
local rest = "nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets" 
foreach comp in `first' `rest'{
    // Your statistical command here
	betafit `comp', muvar(l_sust_growthpc l_unsust_growthpc) vce(robust)
    // Use if-else to distinguish between the first and subsequent iterations
    if `comp' == `first' {
        // First iteration: Use the replace option
        outreg2 using "$outputs\mpi_components_sust_growth_beta", excel label bdec(3) replace
    }
    else {
        // Subsequent iterations: Use the append option
        outreg2 using "$outputs\mpi_components_sust_growth_beta", excel label bdec(3) append
    }
}
*




