********************************************************************************
		*Disaggregated Impacts of Growth on Multidimensional Poverty: 
					*Does the Source of Growth Matter?
********************************************************************************

****************************ROBUSTNESS CHECK BETA REGRESSION********************

clear all

********************************************************************************
/*
*** Set global(s) (already set in 00 Main do file)
*directory where data (Master.dta) is saved
global data "C:\Users\\`c(username)'\Desktop\reproducibility package\1 data"
*directory where do-files are saved
global code "C:\Users\\`c(username)'\Desktop\reproducibility package\2 do-files"
*directory where results table will be saved
global outputs "C:\Users\\`c(username)'\Desktop\reproducibility package\3 outputs"
*/


*******************************************************************************
*Figure B1: GDP
foreach dep in mpi nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets {

    *** load Master data set
    use "$data\Master.dta", replace

    encode ccode, gen(c)
    encode ccode, gen(c_n) // Encode ccode as numeric for by c_n:
    
    ********************************************************************************
    *** Analysis
    ********************************************************************************

    * Create matrices to store coefficients and confidence intervals
    matrix Coef = J(84, 1, .)
    matrix LowerCI = J(84, 1, .)
    matrix UpperCI = J(84, 1, .)
    matrix CountryNames = J(84, 1, .)
    
    forvalues country = 1(1)84 {
        qui reg dl_`dep' c5_dl_gdppc if c != `country', vce(robust)
        gen s = e(sample)
        sort c_n
        by c_n: egen s_w = total(s)
        replace s_w = 1/s_w
        qui reg dl_`dep' c5_dl_gdppc if c != `country' [aweight = s_w], vce(robust)

        * Store the coefficient and confidence intervals
        matrix Coef[`country', 1] = _b[c5_dl_gdppc]
        matrix LowerCI[`country', 1] = _b[c5_dl_gdppc] - invttail(e(df_r), 0.025) * _se[c5_dl_gdppc]
        matrix UpperCI[`country', 1] = _b[c5_dl_gdppc] + invttail(e(df_r), 0.025) * _se[c5_dl_gdppc]

        * Store the country code excluded
		su ccode_n if c == `country'
		local country_name = `r(mean)' 
        matrix CountryNames[`country', 1] = `country_name'
        
        drop s s_w
    }
    
    * Convert matrices to data
    svmat Coef, names(Coef)
    svmat LowerCI, names(LowerCI)
    svmat UpperCI, names(UpperCI)
    svmat CountryNames, names(CountryNames)

    drop country
    * Create a variable for country numbers
    gen country = _n

    * Create a variable for the excluded country names
    gen excluded_country = CountryNames1
    drop CountryNames1

    * Combine into one dataset
    keep country Coef LowerCI UpperCI excluded_country
	kountry excluded_country, from(iso3n)
	
    save "$outputs\Figure B1\GDP\\`dep'_coefficients.dta", replace

    * Load the dataset
    use "$outputs\Figure B1\GDP\\`dep'_coefficients.dta", clear
    drop if Coef1 == .
    
    * Plot the coefficients and confidence intervals
    twoway (rcap LowerCI UpperCI country) (scatter Coef country), ///
        ytitle("Coefficient and CI") ///
        xtitle("Country") ///
        title("Outlier test: `dep' and gdp") ///
		yscale(range(-5 1)) ///
		ylabel(-5(1)1)

    graph export "$outputs\Figure B1\GDP\\`dep'.png", as(png) replace
    clear
}
*

/*
***The following regressions are not shown in the paper for space reasons

********************************************************************************
*labour productivity
foreach dep in mpi nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets {

    *** load Master data set
    use "$data\Master.dta", replace

    encode ccode, gen(c)
    encode ccode, gen(c_n) // Encode ccode as numeric for by c_n:
    
    ********************************************************************************
    *** Analysis
    ********************************************************************************

    * Create matrices to store coefficients and confidence intervals
    matrix Coef = J(84, 1, .)
    matrix LowerCI = J(84, 1, .)
    matrix UpperCI = J(84, 1, .)
    matrix CountryNames = J(84, 1, .)
    
    forvalues country = 1(1)84 {
        qui reg dl_`dep' c5_dl_lpe if c != `country', vce(robust)
        gen s = e(sample)
        sort c_n
        by c_n: egen s_w = total(s)
        replace s_w = 1/s_w
        qui reg dl_`dep' c5_dl_lpe if c != `country' [aweight = s_w], vce(robust)

        * Store the coefficient and confidence intervals
        matrix Coef[`country', 1] = _b[c5_dl_lpe]
        matrix LowerCI[`country', 1] = _b[c5_dl_lpe] - invttail(e(df_r), 0.025) * _se[c5_dl_lpe]
        matrix UpperCI[`country', 1] = _b[c5_dl_lpe] + invttail(e(df_r), 0.025) * _se[c5_dl_lpe]

        * Store the country code excluded
		su ccode_n if c == `country'
		local country_name = `r(mean)' 
        matrix CountryNames[`country', 1] = `country_name'
        
        drop s s_w
    }
    
    * Convert matrices to data
    svmat Coef, names(Coef)
    svmat LowerCI, names(LowerCI)
    svmat UpperCI, names(UpperCI)
    svmat CountryNames, names(CountryNames)

    drop country
    * Create a variable for country numbers
    gen country = _n

    * Create a variable for the excluded country names
    gen excluded_country = CountryNames1
    drop CountryNames1

    * Combine into one dataset
    keep country Coef LowerCI UpperCI excluded_country
	kountry excluded_country, from(iso3n)
	
    save "$outputs\Figure B1\LPE\\`dep'_coefficients.dta", replace

    * Load the dataset
    use "$outputs\Figure B1\LPE\\`dep'_coefficients.dta", clear
    drop if Coef1 == .
    
    * Plot the coefficients and confidence intervals
    twoway (rcap LowerCI UpperCI country) (scatter Coef country), ///
        ytitle("Coefficient and CI") ///
        xtitle("Country") ///
        title("Outlier test: `dep' and labour productivity")

    graph export "$outputs\Figure B1\LPE\\`dep'.png", as(png) replace
    clear
}
*

*******************************************************************************
*labour productivity components
foreach dep in mpi nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets {

    *** load Master data set
    use "$data\Master.dta", replace

    encode ccode, gen(c)
    encode ccode, gen(c_n) // Encode ccode as numeric for by c_n:
    
    ********************************************************************************
    *** Analysis
    ********************************************************************************

    * Create matrices to store coefficients and confidence intervals
    matrix Coef1 = J(84, 1, .)
    matrix LowerCI1 = J(84, 1, .)
    matrix UpperCI1 = J(84, 1, .)
	
	    matrix Coef2 = J(84, 1, .)
    matrix LowerCI2 = J(84, 1, .)
    matrix UpperCI2 = J(84, 1, .)

    matrix Coef3 = J(84, 1, .)
    matrix LowerCI3 = J(84, 1, .)
    matrix UpperCI3 = J(84, 1, .)

    matrix CountryNames = J(84, 1, .)
    
    forvalues country = 1(1)84 {
        qui reg dl_`dep' c5_dl_tfp c5_dl_capdeep c5_dl_hc if c != `country', vce(robust)
        gen s = e(sample)
        sort c_n
        by c_n: egen s_w = total(s)
        replace s_w = 1/s_w
        qui reg dl_`dep' c5_dl_tfp c5_dl_capdeep c5_dl_hc if c != `country' [aweight = s_w], vce(robust)

        * Store the coefficient and confidence intervals
        matrix Coef1[`country', 1] = _b[c5_dl_tfp]
        matrix LowerCI1[`country', 1] = _b[c5_dl_tfp] - invttail(e(df_r), 0.025) * _se[c5_dl_tfp]
        matrix UpperCI1[`country', 1] = _b[c5_dl_tfp] + invttail(e(df_r), 0.025) * _se[c5_dl_tfp]

		matrix Coef2[`country', 1] = _b[ c5_dl_capdeep]
        matrix LowerCI2[`country', 1] = _b[ c5_dl_capdeep] - invttail(e(df_r), 0.025) * _se[ c5_dl_capdeep]
        matrix UpperCI2[`country', 1] = _b[ c5_dl_capdeep] + invttail(e(df_r), 0.025) * _se[ c5_dl_capdeep]

		matrix Coef3[`country', 1] = _b[ c5_dl_hc]
        matrix LowerCI3[`country', 1] = _b[ c5_dl_hc] - invttail(e(df_r), 0.025) * _se[ c5_dl_hc]
        matrix UpperCI3[`country', 1] = _b[ c5_dl_hc] + invttail(e(df_r), 0.025) * _se[ c5_dl_hc]

        * Store the country code excluded
		su ccode_n if c == `country'
		local country_name = `r(mean)' 
        matrix CountryNames[`country', 1] = `country_name'
        
        drop s s_w
    }
    
    * Convert matrices to data
    svmat Coef1, names(Coef1)
    svmat LowerCI1, names(LowerCI1)
    svmat UpperCI1, names(UpperCI1)

	svmat Coef2, names(Coef2)
    svmat LowerCI2, names(LowerCI2)
    svmat UpperCI2, names(UpperCI2)

	svmat Coef3, names(Coef3)
    svmat LowerCI3, names(LowerCI3)
    svmat UpperCI3, names(UpperCI3)

    svmat CountryNames, names(CountryNames)

    drop country
    * Create a variable for country numbers
    gen country = _n

    * Create a variable for the excluded country names
    gen excluded_country = CountryNames1
    drop CountryNames1

    * Combine into one dataset
    keep country Coef* LowerCI* UpperCI* excluded_country
	kountry excluded_country, from(iso3n)
	
    save "$outputs\Figure B1\LPE_comp\\`dep'_coefficients.dta", replace

    * Load the dataset
    use "$outputs\Figure B1\LPE_comp\\`dep'_coefficients.dta", clear
    drop if Coef1 == .
    
    * Plot the coefficients and confidence intervals of tfp
    twoway (rcap LowerCI1 UpperCI1 country) (scatter Coef1 country), ///
        ytitle("Coefficient and CI") ///
        xtitle("Country") ///
        title("Outlier test: `dep' and TFP")
    graph export "$outputs\Figure B1\LPE_comp\\`dep'_tfp.png", as(png) replace
		
	* Plot the coefficients and confidence intervals of of capital deepening
    twoway (rcap LowerCI2 UpperCI2 country) (scatter Coef2 country), ///
        ytitle("Coefficient and CI") ///
        xtitle("Country") ///
        title("Outlier test: `dep' and capital deepening")
    graph export "$outputs\Figure B1\LPE_comp\\`dep'_cd.png", as(png) replace
		
		* Plot the coefficients and confidence intervals of human capital
    twoway (rcap LowerCI3 UpperCI3 country) (scatter Coef3 country), ///
        ytitle("Coefficient and CI") ///
        xtitle("Country") ///
        title("Outlier test: `dep' and human capital")

    graph export "$outputs\Figure B1\LPE_comp\\`dep'_hc.png", as(png) replace
    clear
}
*

********************************************************************************
*expenditure
foreach dep in mpi nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets {

    *** load Master data set
    use "$data\Master.dta", replace

    encode ccode, gen(c)
    encode ccode, gen(c_n) // Encode ccode as numeric for by c_n:
    
    ********************************************************************************
    *** Analysis
    ********************************************************************************

    * Create matrices to store coefficients and confidence intervals
    matrix Coef1 = J(84, 1, .)
    matrix LowerCI1 = J(84, 1, .)
    matrix UpperCI1 = J(84, 1, .)
	
	    matrix Coef2 = J(84, 1, .)
    matrix LowerCI2 = J(84, 1, .)
    matrix UpperCI2 = J(84, 1, .)

    matrix Coef3 = J(84, 1, .)
    matrix LowerCI3 = J(84, 1, .)
    matrix UpperCI3 = J(84, 1, .)

    matrix Coef4 = J(84, 1, .)
    matrix LowerCI4 = J(84, 1, .)
    matrix UpperCI4 = J(84, 1, .)

    matrix Coef5 = J(84, 1, .)
    matrix LowerCI5 = J(84, 1, .)
    matrix UpperCI5 = J(84, 1, .)

    matrix CountryNames = J(84, 1, .)
    
    forvalues country = 1(1)84 {
        qui reg dl_`dep' c5_dl_cpc c5_dl_ipc c5_dl_gpc c5_dl_xpc c5_dl_mpc if c != `country', vce(robust)
        gen s = e(sample)
        sort c_n
        by c_n: egen s_w = total(s)
        replace s_w = 1/s_w
        qui reg dl_`dep' c5_dl_cpc c5_dl_ipc c5_dl_gpc c5_dl_xpc c5_dl_mpc if c != `country' [aweight = s_w], vce(robust)

        * Store the coefficient and confidence intervals
        matrix Coef1[`country', 1] = _b[c5_dl_cpc]
        matrix LowerCI1[`country', 1] = _b[c5_dl_cpc] - invttail(e(df_r), 0.025) * _se[c5_dl_cpc]
        matrix UpperCI1[`country', 1] = _b[c5_dl_cpc] + invttail(e(df_r), 0.025) * _se[c5_dl_cpc]

		matrix Coef2[`country', 1] = _b[ c5_dl_ipc]
        matrix LowerCI2[`country', 1] = _b[ c5_dl_ipc] - invttail(e(df_r), 0.025) * _se[ c5_dl_ipc]
        matrix UpperCI2[`country', 1] = _b[ c5_dl_ipc] + invttail(e(df_r), 0.025) * _se[ c5_dl_ipc]

		matrix Coef3[`country', 1] = _b[ c5_dl_gpc]
        matrix LowerCI3[`country', 1] = _b[ c5_dl_gpc] - invttail(e(df_r), 0.025) * _se[ c5_dl_gpc]
        matrix UpperCI3[`country', 1] = _b[ c5_dl_gpc] + invttail(e(df_r), 0.025) * _se[ c5_dl_gpc]

		matrix Coef4[`country', 1] = _b[ c5_dl_xpc]
        matrix LowerCI4[`country', 1] = _b[ c5_dl_xpc] - invttail(e(df_r), 0.025) * _se[ c5_dl_xpc]
        matrix UpperCI4[`country', 1] = _b[ c5_dl_xpc] + invttail(e(df_r), 0.025) * _se[ c5_dl_xpc]

		matrix Coef5[`country', 1] = _b[ c5_dl_mpc]
        matrix LowerCI5[`country', 1] = _b[ c5_dl_mpc] - invttail(e(df_r), 0.025) * _se[ c5_dl_mpc]
        matrix UpperCI5[`country', 1] = _b[ c5_dl_mpc] + invttail(e(df_r), 0.025) * _se[ c5_dl_mpc]

        * Store the country code excluded
		su ccode_n if c == `country'
		local country_name = `r(mean)' 
        matrix CountryNames[`country', 1] = `country_name'
        
        drop s s_w
    }
    
    * Convert matrices to data
    svmat Coef1, names(Coef1)
    svmat LowerCI1, names(LowerCI1)
    svmat UpperCI1, names(UpperCI1)

	svmat Coef2, names(Coef2)
    svmat LowerCI2, names(LowerCI2)
    svmat UpperCI2, names(UpperCI2)

	svmat Coef3, names(Coef3)
    svmat LowerCI3, names(LowerCI3)
    svmat UpperCI3, names(UpperCI3)
	
	svmat Coef4, names(Coef4)
    svmat LowerCI4, names(LowerCI4)
    svmat UpperCI4, names(UpperCI4)

	svmat Coef5, names(Coef5)
    svmat LowerCI5, names(LowerCI5)
    svmat UpperCI5, names(UpperCI5)


    svmat CountryNames, names(CountryNames)

    drop country
    * Create a variable for country numbers
    gen country = _n

    * Create a variable for the excluded country names
    gen excluded_country = CountryNames1
    drop CountryNames1

    * Combine into one dataset
    keep country Coef* LowerCI* UpperCI* excluded_country
	kountry excluded_country, from(iso3n)
	
    save "$outputs\Figure B1\EXP\\`dep'_coefficients.dta", replace

    * Load the dataset
    use "$outputs\Figure B1\EXP\\`dep'_coefficients.dta", clear
    drop if Coef1 == .
    
    * Plot the coefficients and confidence intervals of c
    twoway (rcap LowerCI1 UpperCI1 country) (scatter Coef1 country), ///
        ytitle("Coefficient and CI") ///
        xtitle("Country") ///
        title("Outlier test: `dep' and consumption")
    graph export "$outputs\Figure B1\EXP\\`dep'_c.png", as(png) replace
		
	* Plot the coefficients and confidence intervals of of i
    twoway (rcap LowerCI2 UpperCI2 country) (scatter Coef2 country), ///
        ytitle("Coefficient and CI") ///
        xtitle("Country") ///
        title("Outlier test: `dep' and investment")
    graph export "$outputs\Figure B1\EXP\\`dep'_i.png", as(png) replace
		
	* Plot the coefficients and confidence intervals of g
    twoway (rcap LowerCI3 UpperCI3 country) (scatter Coef3 country), ///
        ytitle("Coefficient and CI") ///
        xtitle("Country") ///
        title("Outlier test: `dep' and government spending")
	graph export "$outputs\Figure B1\EXP\\`dep'_g.png", as(png) replace
    
	* Plot the coefficients and confidence intervals of x
    twoway (rcap LowerCI4 UpperCI4 country) (scatter Coef4 country), ///
        ytitle("Coefficient and CI") ///
        xtitle("Country") ///
        title("Outlier test: `dep' and export")
	graph export "$outputs\Figure B1\EXP\\`dep'_x.png", as(png) replace

	* Plot the coefficients and confidence intervals of m
    twoway (rcap LowerCI5 UpperCI5 country) (scatter Coef5 country), ///
        ytitle("Coefficient and CI") ///
        xtitle("Country") ///
        title("Outlier test: `dep' and import")
	graph export "$outputs\Figure B1\EXP\\`dep'_m.png", as(png) replace

	
	clear
}
*


********************************************************************************
***Sustainable grwoth
foreach dep in mpi nutrition child_mortality years_of_schooling school_attendance cooking_fuel sanitation drinking_water electricity housing assets {

    *** load Master data set
    use "$data\Master.dta", replace

    encode ccode, gen(c)
    encode ccode, gen(c_n) // Encode ccode as numeric for by c_n:
    
    ********************************************************************************
    *** Analysis
    ********************************************************************************

    * Create matrices to store coefficients and confidence intervals
    matrix Coef1 = J(84, 1, .)
    matrix LowerCI1 = J(84, 1, .)
    matrix UpperCI1 = J(84, 1, .)
	
	matrix Coef2 = J(84, 1, .)
    matrix LowerCI2 = J(84, 1, .)
    matrix UpperCI2 = J(84, 1, .)

    matrix CountryNames = J(84, 1, .)
    
    forvalues country = 1(1)84 {
        qui reg dl_`dep' c5_dl_sust_growthpc c5_dl_unsust_growthpc if c != `country', vce(robust)
        gen s = e(sample)
        sort c_n
        by c_n: egen s_w = total(s)
        replace s_w = 1/s_w
        qui reg dl_`dep' c5_dl_sust_growthpc c5_dl_unsust_growthpc if c != `country' [aweight = s_w], vce(robust)

        * Store the coefficient and confidence intervals
        matrix Coef1[`country', 1] = _b[c5_dl_sust_growthpc]
        matrix LowerCI1[`country', 1] = _b[c5_dl_sust_growthpc] - invttail(e(df_r), 0.025) * _se[c5_dl_sust_growthpc]
        matrix UpperCI1[`country', 1] = _b[c5_dl_sust_growthpc] + invttail(e(df_r), 0.025) * _se[c5_dl_sust_growthpc]

		matrix Coef2[`country', 1] = _b[ c5_dl_unsust_growthpc]
        matrix LowerCI2[`country', 1] = _b[ c5_dl_unsust_growthpc] - invttail(e(df_r), 0.025) * _se[ c5_dl_unsust_growthpc]
        matrix UpperCI2[`country', 1] = _b[ c5_dl_unsust_growthpc] + invttail(e(df_r), 0.025) * _se[ c5_dl_unsust_growthpc]

        * Store the country code excluded
		su ccode_n if c == `country'
		local country_name = `r(mean)' 
        matrix CountryNames[`country', 1] = `country_name'
        
        drop s s_w
    }
    
    * Convert matrices to data
    svmat Coef1, names(Coef1)
    svmat LowerCI1, names(LowerCI1)
    svmat UpperCI1, names(UpperCI1)

	svmat Coef2, names(Coef2)
    svmat LowerCI2, names(LowerCI2)
    svmat UpperCI2, names(UpperCI2)

    svmat CountryNames, names(CountryNames)

    drop country
    * Create a variable for country numbers
    gen country = _n

    * Create a variable for the excluded country names
    gen excluded_country = CountryNames1
    drop CountryNames1

    * Combine into one dataset
    keep country Coef* LowerCI* UpperCI* excluded_country
	kountry excluded_country, from(iso3n)
	
    save "$outputs\Figure B1\SUST\\`dep'_coefficients.dta", replace

    * Load the dataset
    use "$outputs\Figure B1\SUST\\`dep'_coefficients.dta", clear
    drop if Coef1 == .
    
    * Plot the coefficients and confidence intervals of sustainable
    twoway (rcap LowerCI1 UpperCI1 country) (scatter Coef1 country), ///
        ytitle("Coefficient and CI") ///
        xtitle("Country") ///
        title("Outlier test: `dep' and sustainable growth")
    graph export "$outputs\Figure B1\SUST\\`dep'_sust.png", as(png) replace
		
	* Plot the coefficients and confidence intervals of of unsustainable
    twoway (rcap LowerCI2 UpperCI2 country) (scatter Coef2 country), ///
        ytitle("Coefficient and CI") ///
        xtitle("Country") ///
        title("Outlier test: `dep' and unsustainable growth")
    graph export "$outputs\Figure B1\SUST\\`dep'_unsust.png", as(png) replace
		
	
	clear
}
*
